/*
 * Copyright 2005-2012 Schlichtherle IT Services
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 */
package de.schlichtherle.swing;

import java.awt.Insets;
import javax.swing.BorderFactory;
import javax.swing.border.EmptyBorder;
import javax.swing.border.TitledBorder;

/**
 * This class represents an {@link EmptyBorder} with the same
 * insets as a {@link TitledBorder}.
 *
 * @author Christian Schlichtherle
 */
public class InvisibleTitledBorder extends EmptyBorder {

    private static InvisibleTitledBorder INSTANCE = createEmptyTitledBorder();
    private static final long serialVersionUID = 1L;

    /**
     * @deprecated Use {@link #getInstance} instead.
     */
    public static InvisibleTitledBorder createEmptyTitledBorder() {
        TitledBorder prototype = BorderFactory.createTitledBorder(null, "Test"); // NOI18N
        return new InvisibleTitledBorder(prototype.getBorderInsets(null));
    }

    /**
     * Returns the default instance of this class.
     */
    public static InvisibleTitledBorder getInstance() {
        return INSTANCE;
    }
    
    /** You cannot instantiate this class. */
    protected InvisibleTitledBorder(Insets borderInsets) {
        super(borderInsets);
    }
}
