/*
 * Copyright 2005-2012 Schlichtherle IT Services
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 */
package de.schlichtherle.swing;

import java.awt.Component;
import java.awt.Container;
import java.awt.Window;

/**
 * @author Christian Schlichtherle
 */
public class SwingUtilities {

    /**
     * Executes the given runnable from the AWT Event Dispatcher Thread,
     * even if this method is executed by the EDT.
     */
    public static void runOnEventDispatchThread(final Runnable r)
    throws java.lang.reflect.InvocationTargetException {
        if (javax.swing.SwingUtilities.isEventDispatchThread()) {
            r.run();
        } else {
            try {
                javax.swing.SwingUtilities.invokeAndWait(r);
            } catch (InterruptedException interrupted) {
                interrupted.printStackTrace();
            }
        }
    }
    
    /**
     * Returns the ancestor {@link Window} of the given {@code component}
     * or {@code null} if the component is not (yet) placed in a
     * {@code Window}.
     */
    public static Window getAncestorWindow(final Component component) {
        Container parent = component.getParent();
        while (parent != null && !(parent instanceof Window))
            parent = parent.getParent();

        return (Window) parent;
    }
    
    protected SwingUtilities() { } // You cannot instantiate this class
}
